@@ -1,6 +1,7 @@
 import os
 
 import streamlit.components.v1 as components
+import streamlit as st
 
 
 _RELEASE = True
@@ -20,3 +21,5 @@ def StreamlitCookies(name=None, act=None, value=None, key=None):
     response = cookie_func(name=name, value=value, act=act, key=key)
     return response
 
+
+st.write(StreamlitCookies(name="name"))
\ No newline at end of file
